/***************************************************************************
 *            book-fun.c
 *
 *  Mon Oct 31 20:46:48 2005
 *  Copyright  2005  Tomek Jankowski
 *  Email	tomcio-j@o2.pl
 ****************************************************************************/

/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
/*=====================================================================
 *	Plik zawiera wspolne funkcje dla wszytskich typow ksiazek
 *====================================================================*/
 
#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <glade/glade.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gprintf.h>
#include <glib/gi18n-lib.h>
#include <stdio.h>

#include "book-fun.h"
#include "database-fun.h"
#include "interface-fun.h"

#define SHORT_STRING	128
#define MEDIUM_STRING	256

/*
 *	Funkcja laduje tytuly wszystkich typow ksiazek to listy 'main_list' w oknie 
 *	'main_win'. Po zaladowaniu tytulow funkcja pokzauje poczatkowo schowana 
 *	liste 'main_list'.
 */

void	load_books_titles	(void)	{
	GladeXML			*xml;
	GtkWidget			*treeview;
	GtkTreeModel		*store;
	GtkTreeIter 		iter;	
	GtkTreeIter			parent;
	gint				status;
	gint				rows;
	gchar				sql_query	[MEDIUM_STRING];
	sqlite3_stmt		*db_row;
	sqlite3_stmt		*child_db_row;
	
	status = 0;
	set_statusbar_text (_("Loading books..."));
	
	xml = glade_get_widget_tree (main_win);
	treeview = glade_xml_get_widget (xml, "main_list");
	gtk_widget_hide (treeview);
	
	store = gtk_tree_view_get_model (GTK_TREE_VIEW (treeview));
	
	g_printf(">>> Loading books titles, counting books...\n");
	
	/*	Ksiazki jednotomowe	*/
	rows = count_returned_rows ("SELECT COUNT(id) FROM single_volume_books;");
	g_printf ("<<< Single books in database: %d\n", rows);
	
	sqlite3_prepare (database, "SELECT id, title FROM single_volume_books;", -1, &db_row, 0);	
	
	status = sqlite3_step (db_row);
	if (rows > 0)	{
		while (status == 100)		{
			gtk_tree_store_append (GTK_TREE_STORE (store), &iter, NULL);
			gtk_tree_store_set (GTK_TREE_STORE (store), &iter,
								0, sqlite3_column_int (db_row, 0), 
								1, sqlite3_column_text (db_row, 1),
								2, _("Single volume"),
								3, 0, /*	to pole jest ukryte	*/
								-1);
			status = sqlite3_step (db_row);
		}
	}
	sqlite3_finalize (db_row);
	
	/*	Ksiazki wielotomowe	*/
	rows = count_returned_rows ("SELECT COUNT(id) FROM multi_volume_books_shared_data;");
	g_printf ("<<< Multi books in database: %d\n", rows);
	
	sqlite3_prepare (database, "SELECT id, title FROM multi_volume_books_shared_data;", -1, &db_row, 0);	
	
	status = sqlite3_step (db_row);
	if (rows > 0)	{
		while (status == 100)		{
			gtk_tree_store_append (GTK_TREE_STORE (store), &parent, NULL);
			gtk_tree_store_set (GTK_TREE_STORE (store), &parent,
								0, sqlite3_column_int (db_row, 0), 
								1, sqlite3_column_text (db_row, 1),
								2, _("Multi volume"),
								3, 1, /*	to pole jest ukryte	*/
								-1);
			/*	Pozycje wchodzace w sklad ksiazek wielotomowych	*/
			g_sprintf (sql_query, "SELECT id, title FROM multi_volume_books_private_data WHERE multi_id=%d;",
				sqlite3_column_int (db_row, 0));
			sqlite3_prepare (database, sql_query, -1, &child_db_row, 0);
			status = sqlite3_step (child_db_row);	
			while (status == 100)		{
				gtk_tree_store_append (GTK_TREE_STORE (store), &iter, &parent);
				gtk_tree_store_set (GTK_TREE_STORE (store), &iter,
									0, sqlite3_column_int (child_db_row, 0), 
									1, sqlite3_column_text (child_db_row, 1),
									2, "",
									3, 2, /*	to pole jest ukryte	*/
									-1);
				status = sqlite3_step (child_db_row);
			}
			sqlite3_finalize (child_db_row);
			
			status = sqlite3_step (db_row);
		}
	}
	sqlite3_finalize (db_row);
	/*	Pokazujemy listen*/
	gtk_widget_show (treeview);
}

/*
 *	Funkcja odswieza liste 'main_list' w oknie 'main_win'.
 */

void		refresh_main_list			(void)	{
	GladeXML	*xml;
	GtkWidget	*widget;
	
	xml = glade_get_widget_tree (main_win);
	widget = glade_xml_get_widget (xml, "main_list");
	gtk_widget_hide (widget);
	clear_tree_list (widget);
	load_books_titles ();
	gtk_widget_show (widget);
	/*	Ustawiamy pusta zakladke w oknie 'maon_win'	*/
	widget = glade_xml_get_widget (xml, "main_notebook");
	gtk_notebook_set_current_page (GTK_NOTEBOOK (widget), 0);
}

/*
 *	Funkcja zapisuje imie i nazwisko autora do zmiennej 'string', ktorej wskaznik
 *	zostal przekazany w argumencie.
 */

void	get_author_name	(gchar	*string, gint	id)	{
	gint				status;
	gchar				sql_query	[SHORT_STRING];
	sqlite3_stmt		*db_row;
	
	g_sprintf (sql_query, "SELECT author FROM authors WHERE id=%d;",
				id);
	sqlite3_prepare (database, sql_query, -1, &db_row, 0);
	status = sqlite3_step (db_row);
	g_printf ("\t<<< Selecting author from database, SQLite result: %d\n", status);	
	
	g_sprintf (string, "%s", sqlite3_column_text (db_row, 0));
	sqlite3_finalize (db_row);
}

/*
 *	Zwraca numer ID autora podanego w parametrze 'string', jezeli 'string'
 *	jest pusty zwracane jest 0.
 */

gint	get_author_id			(gchar	*string)	{
	gint				status;
	gint				id;
	gchar				sql_query	[SHORT_STRING];
	sqlite3_stmt		*db_row;
	
	/*	Nie sprawdzamy numeru ID gdy dostaniemy pusty ciag - '(null)'	*/
	if (strcmp (string, "(null)") == 0)
		return 0;
	
	g_sprintf (sql_query, "SELECT id FROM authors WHERE author=\'%s\';", 
					string);
	sqlite3_prepare (database, sql_query, -1, &db_row, 0);
	status = sqlite3_step (db_row);
	g_printf ("\t<<< Getting author ID, SQLite result: %d\n", status);
	id = sqlite3_column_int (db_row, 0);
	sqlite3_finalize (db_row);
	
	return id;
}

/*
 *	Funkcja zapisuje nazwe gatunku do zmiennej 'string', ktorej wskaznik
 *	zostal przekazany w argumencie.
 */

void	get_genere_name	(gchar	*string, gint	id)	{
	gint				status;
	gchar				sql_query	[SHORT_STRING];
	sqlite3_stmt		*db_row;
	
	g_sprintf (sql_query, "SELECT genere FROM generes WHERE id=%d;",
				id);
	sqlite3_prepare (database, sql_query, -1, &db_row, 0);
	status = sqlite3_step (db_row);
	g_printf ("\t<<< Selecting genre from database, SQLite result: %d\n", status);	
	
	g_sprintf (string, "%s", sqlite3_column_text (db_row, 0));
	sqlite3_finalize (db_row);
}

/*
 *	Zwraca numer ID gatunku podanego w parametrze 'string', jezeli 'string'
 *	jest pusty zwracane jest 0.
 */

gint	get_genere_id			(gchar	*string)	{
	gint				status;
	gint				id;
	gchar				sql_query	[SHORT_STRING];
	sqlite3_stmt		*db_row;
	
	/*	Nie sprawdzamy numeru ID gdy dostaniemy pusty ciag - '(null)'	*/
	if (strcmp (string, "(null)") == 0)
		return 0;
	
	g_sprintf (sql_query, "SELECT id FROM generes WHERE genere=\'%s\';", 
					string);
	sqlite3_prepare (database, sql_query, -1, &db_row, 0);
	status = sqlite3_step (db_row);
	g_printf ("\t<<< Getting genre ID, SQLite result: %d\n", status);
	id = sqlite3_column_int (db_row, 0);
	sqlite3_finalize (db_row);
	
	return id;
}

/*
 *	Funkcja zapisuje nazwe wydawnictwa do zmiennej 'string', ktorej wskaznik
 *	zostal przekazany w argumencie.
 */

void	get_publish_house_name	(gchar	*string, gint	id)	{
	gint				status;
	gchar				sql_query	[SHORT_STRING];
	sqlite3_stmt		*db_row;
	
	g_sprintf (sql_query, "SELECT publish_house FROM publish_houses WHERE id=%d;",
				id);
	sqlite3_prepare (database, sql_query, -1, &db_row, 0);
	status = sqlite3_step (db_row);
	g_printf ("\t<<< Selecting publish house from database, SQLite result: %d\n", status);	
	
	g_sprintf (string, "%s", sqlite3_column_text (db_row, 0));
	sqlite3_finalize (db_row);
}

/*
 *	Zwraca numer ID wydawnictwa podanego w parametrze 'string', jezeli 'string'
 *	jest pusty zwracane jest 0.
 */

gint	get_publish_house_id	(gchar	*string)	{
	gint				status;
	gint				id;
	gchar				sql_query	[SHORT_STRING];
	sqlite3_stmt		*db_row;
	
	/*	Nie sprawdzamy numeru ID gdy dostaniemy pusty ciag - '(null)'	*/
	if (strcmp (string, "(null)") == 0)
		return 0;
	
	g_sprintf (sql_query, "SELECT id FROM publish_houses WHERE publish_house=\'%s\';", 
					string);
	sqlite3_prepare (database, sql_query, -1, &db_row, 0);
	status = sqlite3_step (db_row);
	g_printf ("\t<<< Getting publish house ID, SQLite result: %d\n", status);
	id = sqlite3_column_int (db_row, 0);
	sqlite3_finalize (db_row);
	
	return id;
}

/*
 *	Funkcja zapisuje nazwe jezyka do zmiennej 'string', ktorej wskaznik
 *	zostal przekazany w argumencie.
 */

void	get_language_name	(gchar	*string, gint	id)	{
	gint				status;
	gchar				sql_query	[SHORT_STRING];
	sqlite3_stmt		*db_row;
	
	g_sprintf (sql_query, "SELECT language FROM languages WHERE id=%d;",
				id);
	sqlite3_prepare (database, sql_query, -1, &db_row, 0);
	status = sqlite3_step (db_row);
	g_printf ("\t<<< Selecting language from database, SQLite result: %d\n", status);	
	
	g_sprintf (string, "%s", sqlite3_column_text (db_row, 0));
	sqlite3_finalize (db_row);
}

/*
 *	Zwraca numer ID jesyka podanego w parametrze 'string', jezeli 'string'
 *	jest pusty zwracane jest 0.
 */

gint	get_language_id	(gchar	*string)	{
	gint				status;
	gint				id;
	gchar				sql_query	[SHORT_STRING];
	sqlite3_stmt		*db_row;
	
	/*	Nie sprawdzamy numeru ID gdy dostaniemy pusty ciag - '(null)'	*/
	if (strcmp (string, "(null)") == 0)
		return 0;
	
	g_sprintf (sql_query, "SELECT id FROM languages WHERE language=\'%s\';", 
					string);
	sqlite3_prepare (database, sql_query, -1, &db_row, 0);
	status = sqlite3_step (db_row);
	g_printf ("\t<<< Getting language ID, SQLite result: %d\n", status);
	id = sqlite3_column_int (db_row, 0);
	sqlite3_finalize (db_row);
	
	return id;
}

/*
 *	Funkcja zapisuje imie i nazwisko tlumacza do zmiennej 'string', ktorej wskaznik
 *	zostal przekazany w argumencie.
 */

void	get_translator_name	(gchar	*string, gint	id)	{
	gint				status;
	gchar				sql_query	[SHORT_STRING];
	sqlite3_stmt		*db_row;
	
	g_sprintf (sql_query, "SELECT translator FROM translators WHERE id=%d;",
				id);
	sqlite3_prepare (database, sql_query, -1, &db_row, 0);
	status = sqlite3_step (db_row);
	g_printf ("\t<<< Selecting translator from database, SQLite result: %d\n", status);	
	
	g_sprintf (string, "%s", sqlite3_column_text (db_row, 0));
	sqlite3_finalize (db_row);
}

/*
 *	Zwraca numer ID tlumacza podanego w parametrze 'string', jezeli 'string'
 *	jest pusty zwracane jest 0.
 */

gint	get_translator_id			(gchar	*string)	{
	gint				status;
	gint				id;
	gchar				sql_query	[SHORT_STRING];
	sqlite3_stmt		*db_row;
	
	/*	Nie sprawdzamy numeru ID gdy dostaniemy pusty ciag - '(null)'	*/
	if (strcmp (string, "(null)") == 0)
		return 0;
	
	g_sprintf (sql_query, "SELECT id FROM translators WHERE translator=\'%s\';", 
					string);
	sqlite3_prepare (database, sql_query, -1, &db_row, 0);
	status = sqlite3_step (db_row);
	g_printf ("\t<<< Getting translator ID, SQLite result: %d\n", status);
	id = sqlite3_column_int (db_row, 0);
	sqlite3_finalize (db_row);
	
	return id;
}
