/***************************************************************************
 *            m_book_win-callbacks.c
 *
 *  Sat Oct 22 21:25:35 2005
 *  Copyright  2005  Tomek Jankowski
 *  Email	tomcio-j@o2.pl
 ****************************************************************************/

/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <glade/glade.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gprintf.h>
#include <glib/gi18n-lib.h>
#include <stdio.h>

#include "m_book_win-callbacks.h"
#include "m_volume_win-callbacks.h"
#include "m_volume_win-callbacks.h"
#include "interface-fun.h"
#include "m_book-fun.h"
#include "m_volume-fun.h"

#define VERY_SHORT_STRING	12
#define SHORT_STRING		128

gboolean
on_m_book_win_delete_event             (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data)
{
	gboolean	result;
	result = show_question_dlg (_("Quit without saving?"), _("If you quit now, "
				"you will lose all changes. Do you want to continue?"), 0);
	if (result == TRUE)	{
		m_volume_free_memory (widget);
		destroy_window (widget);
	}
	return FALSE;
}


void
on_m_first_author_en_changed           (GtkEditable     *editable,
                                        gpointer         user_data)
{
	GtkWidget	*widget;
	GladeXML	*xml;
	
	xml = glade_get_widget_tree (GTK_WIDGET (editable));
	widget = glade_xml_get_widget (xml, "m_first_author_en");	
	
	/*	Jezeli pierwsze pole 'Author' jest puste to element rozszerzajacy 
	 *	'additional_authors_exp' zostanie dezaktywowany, a 'ptaszki'
	 *	przy dodatkowych autorach zostana odznaczone. Robimy to w celu
	 *	zachowania logiki uzywania programu: dodatkowi autorzy moga byc dodani 
	 *	jedyne w sytuacji, gdy podany jest pierwszy autor.	*/

	if (strcmp (gtk_entry_get_text (GTK_ENTRY (widget)), "") == 0)	{
		set_widget_sensinitive (widget, "additional_authors_exp", FALSE);
	}
	else	{
		set_widget_sensinitive (widget, "additional_authors_exp", TRUE);
	}
}


void
on_books_list_row_activated            (GtkTreeView     *treeview,
                                        GtkTreePath     *path,
                                        GtkTreeViewColumn *column,
                                        gpointer         user_data)
{
	
}


void
on_books_list_cursor_changed           (GtkTreeView     *treeview,
                                        gpointer         user_data)
{
	GladeXML			*xml;
	GtkTreeSelection	*selection;
	GtkTreeModel		*model;
  	GtkTreeIter			iter;
	GtkWidget			*widget;
	gint				remove_val;
	
	xml = glade_get_widget_tree (GTK_WIDGET (treeview));
	selection = gtk_tree_view_get_selection (treeview);
	gtk_tree_selection_get_selected (selection, &model, &iter);
	gtk_tree_model_get (model, &iter, 3, &remove_val, -1);
	
	if (remove_val == 0)	{
		set_widget_sensinitive (GTK_WIDGET (treeview), "remove_select_but", TRUE);
		set_widget_sensinitive (GTK_WIDGET (treeview), "remove_unselect_but", FALSE);
	}
	else if (remove_val == 1)	{
		set_widget_sensinitive (GTK_WIDGET (treeview), "remove_select_but", FALSE);
		set_widget_sensinitive (GTK_WIDGET (treeview), "remove_unselect_but", TRUE);
	}
	set_widget_sensinitive (GTK_WIDGET (treeview), "edit_volume_but", TRUE);
}



void
on_add_volume_but_clicked              (GtkButton       *button,
                                        gpointer         user_data)
{
	GtkWidget	*widget;	
	widget = create_m_volume_dlg (GTK_WIDGET (button), 0);
	gtk_widget_show (widget);
	m_volume_prepare_win (GTK_WIDGET (button), widget);
}


void
on_edit_volume_but_clicked             (GtkButton       *button,
                                        gpointer         user_data)
{	
	GladeXML					*xml;
	GtkWidget					*widget;
		
	widget = create_m_volume_dlg (GTK_WIDGET (button), 1);
	gtk_widget_show (widget);
	m_volume_prepare_win (GTK_WIDGET (button), widget);
	
	m_volume_load_win (widget, GTK_WIDGET (button));

	set_widget_sensinitive (GTK_WIDGET (button), "books_list", FALSE);
	set_widget_sensinitive (GTK_WIDGET (button), "edit_volume_but", FALSE);
	set_widget_sensinitive (GTK_WIDGET (button), "remove_select_but", FALSE);
	set_widget_sensinitive (GTK_WIDGET (button), "remove_unselect_but", FALSE);
	set_widget_sensinitive (GTK_WIDGET (button), "remove_unselect_but", FALSE);
}


void
on_remove_select_but_clicked           (GtkButton       *button,
                                        gpointer         user_data)
{
	GladeXML			*xml;
	GtkTreeSelection	*selection;
	GtkTreeModel		*model;
  	GtkTreeIter			iter;
	GtkWidget			*widget;
	gint				item_id;
	gboolean			result;
	
	xml = glade_get_widget_tree (GTK_WIDGET (button));
	widget = glade_xml_get_widget (xml, "books_list"); 
	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (widget));
	gtk_tree_selection_get_selected (selection, &model, &iter);	

	gtk_list_store_set (GTK_LIST_STORE (model), &iter,
								3, 1,
								-1);
	/*	Odznaczamy wszystkie zaznaczone wiersze	*/
	gtk_tree_selection_unselect_all (selection);	
	
	set_widget_sensinitive (GTK_WIDGET (button), "remove_select_but", FALSE);
	set_widget_sensinitive (GTK_WIDGET (button), "remove_unselect_but", FALSE);
	set_widget_sensinitive (GTK_WIDGET (button), "edit_volume_but", FALSE);
}


void
on_remove_unselect_but_clicked         (GtkButton       *button,
                                        gpointer         user_data)
{
	GladeXML			*xml;
	GtkTreeSelection	*selection;
	GtkTreeModel		*model;
  	GtkTreeIter			iter;
	GtkWidget			*widget;
	gint				item_id;
	gboolean			result;
	
	xml = glade_get_widget_tree (GTK_WIDGET (button));
	widget = glade_xml_get_widget (xml, "books_list"); 
	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (widget));
	gtk_tree_selection_get_selected (selection, &model, &iter);	
	
	gtk_list_store_set (GTK_LIST_STORE (model), &iter,
								3, 0,
								-1);
	/*	Odznaczamy wszystkie zaznaczone wiersze	*/
	gtk_tree_selection_unselect_all (selection);
	
	set_widget_sensinitive (GTK_WIDGET (button), "remove_select_but", FALSE);
	set_widget_sensinitive (GTK_WIDGET (button), "remove_unselect_but", FALSE);
	set_widget_sensinitive (GTK_WIDGET (button), "edit_volume_but", FALSE);
}

void
on_m_book_cancel_but_clicked           (GtkButton       *button,
                                        gpointer         user_data)
{
	gboolean	result;
	result = show_question_dlg (_("Quit without saving?"), _("If you quit now, "
				"you will lose all changes. Do you want to continue?"), 0);
	if (result == TRUE)	{
		m_volume_free_memory (GTK_WIDGET (button));
		destroy_window (GTK_WIDGET (button));
	}
}


void
on_m_book_save_but_clicked             (GtkButton       *button,
                                        gpointer         user_data)
{
	if (m_check_book_data (GTK_WIDGET (button)))	{
		MultiVolSharedDataStruc		*book_data;
		GladeXML					*xml;
		GtkTreeModel				*model;
  		GtkTreeIter					iter;
		GtkWidget					*tmp;
		gboolean					result;

		
		/*	Dodawanie ksiazki moze troche potrwac, dlatego dezaktywujemy okno	*/
		set_widget_sensinitive (GTK_WIDGET (button), "m_book_win", FALSE);
		m_check_linked_book_data (GTK_WIDGET (button));
		book_data = m_get_data_from_win (GTK_WIDGET (button));
		m_insert_book (book_data);
		
		/*	Dodajemy tomy	*/
		m_volume_check_linked_data (GTK_WIDGET (button));
		m_volume_insert_volumes (GTK_WIDGET (button), 0);
		
		m_volume_free_memory (GTK_WIDGET (button));
		destroy_window (GTK_WIDGET (button));
		refresh_main_list ();
	}
}


void
on_m_book_update_but_clicked           (GtkButton       *button,
                                        gpointer         user_data)
{
	if (m_check_book_data (GTK_WIDGET (button)))	{
		MultiVolSharedDataStruc	*book_data;
		
		m_check_linked_book_data (GTK_WIDGET (button));
		book_data = m_get_data_from_win (GTK_WIDGET (button));
		m_update_book (book_data);
		
		/*	Aktualizujemy tomy	*/
		m_volume_insert_volumes (GTK_WIDGET (button), 1);
		m_volume_remove_volumes (GTK_WIDGET (button));
		m_volume_check_linked_data (GTK_WIDGET (button));
		m_volume_update_volumes_data (GTK_WIDGET (button));
			
		m_volume_free_memory (GTK_WIDGET (button));
		destroy_window (GTK_WIDGET (button));
		refresh_main_list ();
	}
}

void
on_m_book_same_translators_chbox_clicked
                                        (GtkButton       *button,
                                         gpointer         user_data)
{
	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)	{
		m_set_same_data_status (GTK_WIDGET (button), 1, 1);
		set_widget_sensinitive (GTK_WIDGET (button), "same_translator_hbox", TRUE);
	}
	else	{
		m_set_same_data_status (GTK_WIDGET (button), 1, 0);
		set_widget_sensinitive (GTK_WIDGET (button), "same_translator_hbox", FALSE);
	}
}


void
on_m_same_first_translator_en_changed
                                        (GtkEditable     *editable,
                                         gpointer         user_data)
{
	GtkWidget	*widget;
	GladeXML	*xml;
	
	xml = glade_get_widget_tree (GTK_WIDGET (editable));
	widget = glade_xml_get_widget (xml, "m_same_first_translator_en");	
	
	/*	Jezeli pierwsze pole 'Author' jest puste to element rozszerzajacy 
	 *	'additional_authors_exp' zostanie dezaktywowany, a 'ptaszki'
	 *	przy dodatkowych autorach zostana odznaczone. Robimy to w celu
	 *	zachowania logiki uzywania programu: dodatkowi autorzy moga byc dodani 
	 *	jedyne w sytuacji, gdy podany jest pierwszy autor.	*/

	if (strcmp (gtk_entry_get_text (GTK_ENTRY (widget)), "") == 0)	{
		set_widget_sensinitive (widget, "same_additional_translators_exp", FALSE);
	}
	else	{
		set_widget_sensinitive (widget, "same_additional_translators_exp", TRUE);
	}
}


void
on_m_book_same_publish_year_check_clicked
                                        (GtkButton       *button,
                                         gpointer         user_data)
{
	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)	{
		m_set_same_data_status (GTK_WIDGET (button), 0, 1);
		set_widget_sensinitive (GTK_WIDGET (button), "same_publish_year_hbox", TRUE);
	}
	else	{
		m_set_same_data_status (GTK_WIDGET (button), 0, 0);
		set_widget_sensinitive (GTK_WIDGET (button), "same_publish_year_hbox", FALSE);
	}
}
