 /***************************************************************************
 *            s_book_win-callbacks.h
 *
 *  Sat Oct 22 14:08:56 2005
 *  Copyright  2005  Tomek Jankowski
 *  Email	tomcio-j@o2.pl
 ****************************************************************************/

/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <glade/glade.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gprintf.h>
#include <glib/gi18n-lib.h>
#include <stdio.h>

#include "s_book_win-callbacks.h"
#include "s_book-fun.h"
#include "book-fun.h"
#include "interface-fun.h"

gboolean
on_s_book_win_delete_event             (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data)
{
	gboolean	result;
	result = show_question_dlg (_("Quit without saving?"), _("If you quit now, "
				"you will lose all changes. Do you want to continue?"), 0);
	if (result == TRUE)
		destroy_window (widget);
	return FALSE;
}

void
on_s_book_cancel_but_clicked           (GtkButton       *button,
                                        gpointer         user_data)
{
	gboolean	result;
	result = show_question_dlg (_("Quit without saving?"), _("If you quit now, "
				"you will lose all changes. Do you want to continue?"), 0);
	if (result == TRUE)
		destroy_window (GTK_WIDGET (button));
}

void
on_s_book_save_but_clicked             (GtkButton       *button,
                                        gpointer         user_data)
{
	if (s_check_book_data (GTK_WIDGET (button)))	{
		SingleVolumeStruc	*book_data;
		s_check_linked_book_data (GTK_WIDGET (button));
		
		book_data = s_get_data_from_win (GTK_WIDGET (button));
		s_insert_book (book_data);
		destroy_window (GTK_WIDGET (button));
		
		refresh_main_list ();
	}
}

void
on_s_book_update_but_clicked           (GtkButton       *button,
                                        gpointer         user_data)
{
	if (s_check_book_data (GTK_WIDGET (button)))	{
		SingleVolumeStruc	*book_data;
		s_check_linked_book_data (GTK_WIDGET (button));
		
		book_data = s_get_data_from_win (GTK_WIDGET (button));
		s_update_book (book_data);
		destroy_window (GTK_WIDGET (button));
		
		refresh_main_list ();
	}
}

void
on_s_second_author_check_clicked       (GtkButton       *button,
                                        gpointer         user_data)
{
	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
		set_widget_sensinitive (GTK_WIDGET (button), "second_author_en", TRUE);
	else
		set_widget_sensinitive (GTK_WIDGET (button), "second_author_en", FALSE);
}


void
on_s_third_author_check_clicked        (GtkButton       *button,
                                        gpointer         user_data)
{
	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
		set_widget_sensinitive (GTK_WIDGET (button), "third_author_en", TRUE);
	else
		set_widget_sensinitive (GTK_WIDGET (button), "third_author_en", FALSE);
}


void
on_s_second_tralslator_check_clicked   (GtkButton       *button,
                                        gpointer         user_data)
{
	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
		set_widget_sensinitive (GTK_WIDGET (button), "second_translator_en", TRUE);
	else
		set_widget_sensinitive (GTK_WIDGET (button), "second_translator_en", FALSE);
}


void
on_s_third_translator_check_clicked    (GtkButton       *button,
                                        gpointer         user_data)
{
	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
		set_widget_sensinitive (GTK_WIDGET (button), "third_translator_en", TRUE);
	else
		set_widget_sensinitive (GTK_WIDGET (button), "third_translator_en", FALSE);
}

void
on_s_first_author_en_changed             (GtkEditable     *editable,
                                        gpointer         user_data)
{
	GtkWidget	*widget;
	GladeXML	*xml;
	
	xml = glade_get_widget_tree (GTK_WIDGET (editable));
	widget = glade_xml_get_widget (xml, "s_first_author_en");	
	
	/*	Jezeli pierwsze pole 'Author' jest puste to element rozszerzajacy 
	 *	'additional_authors_exp' zostanie dezaktywowany, a 'ptaszki'
	 *	przy dodatkowych autorach zostana odznaczone. Robimy to w celu
	 *	zachowania logiki uzywania programu: dodatkowi autorzy moga byc dodani 
	 *	jedyne w sytuacji, gdy podany jest pierwszy autor.	*/

	if (strcmp (gtk_entry_get_text (GTK_ENTRY (widget)), "") == 0)	{
		set_widget_sensinitive (widget, "additional_authors_exp", FALSE);
		widget = glade_xml_get_widget (xml, "second_author_check");
		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), FALSE);
		widget = glade_xml_get_widget (xml, "third_author_check");
		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), FALSE);
	}
	else	{
		set_widget_sensinitive (widget, "additional_authors_exp", TRUE);
	}
}

void
on_s_first_translator_en_changed         (GtkEditable     *editable,
                                        gpointer         user_data)
{
	GtkWidget	*widget;
	GladeXML	*xml;
	
	xml = glade_get_widget_tree (GTK_WIDGET (editable));
	widget = glade_xml_get_widget (xml, "s_first_translator_en");	
	
	/*	Jezeli pierwsze pole 'Author' jest puste to element rozszerzajacy 
	 *	'additional_authors_exp' zostanie dezaktywowany, a 'ptaszki'
	 *	przy dodatkowych autorach zostana odznaczone. Robimy to w celu
	 *	zachowania logiki uzywania programu: dodatkowi autorzy moga byc dodani 
	 *	jedyne w sytuacji, gdy podany jest pierwszy autor.	*/

	if (strcmp (gtk_entry_get_text (GTK_ENTRY (widget)), "") == 0)	{
		set_widget_sensinitive (widget, "additional_translators_exp", FALSE);
		widget = glade_xml_get_widget (xml, "second_translator_check");
		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), FALSE);
		widget = glade_xml_get_widget (xml, "third_translator_check");
		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), FALSE);
	}
	else	{
		set_widget_sensinitive (widget, "additional_translators_exp", TRUE);
	}
}
